#define TX_PULSESHAPER_4800_GAIN        1.000000f
#define TX_PULSESHAPER_4800_COEFF_SETS  5
static const float tx_pulseshaper_4800[TX_PULSESHAPER_4800_COEFF_SETS][9] =
{
    {
           0.0020271599f,     /* Filter 0 */
           0.0151309301f,
          -0.0054150603f,
          -0.1159724004f,
           0.7564986175f,
           0.4025541225f,
          -0.0341116438f,
          -0.0195424323f,
           0.0049156270f
    },
    {
          -0.0057440210f,     /* Filter 1 */
           0.0153306246f,
           0.0229274754f,
          -0.1619857959f,
           1.0359919667f,
           0.0880056950f,
           0.0268484406f,
          -0.0134684459f,
          -0.0061664697f
    },
    {
          -0.0101543455f,     /* Filter 2 */
           0.0030462995f,
           0.0426482259f,
          -0.1066205465f,
           1.1421607333f,
          -0.1066205466f,
           0.0426482259f,
           0.0030462995f,
          -0.0101543455f
    },
    {
          -0.0061664697f,     /* Filter 3 */
          -0.0134684458f,
           0.0268484406f,
           0.0880056950f,
           1.0359919667f,
          -0.1619857959f,
           0.0229274754f,
           0.0153306246f,
          -0.0057440210f
    },
    {
           0.0049156270f,     /* Filter 4 */
          -0.0195424323f,
          -0.0341116438f,
           0.4025541225f,
           0.7564986174f,
          -0.1159724004f,
          -0.0054150603f,
           0.0151309301f,
           0.0020271599f
    }
};
